@@ -1,9 +1,11 @@
 import resource
 import copy
 import cPickle
+import netCDF4
+import psutil
 
-import sys
-
+from numpy import __file__          as numpy__file__
+from numpy import __version__       as numpy__version__
 from numpy import all               as numpy_all
 from numpy import allclose          as numpy_allclose
 from numpy import array             as numpy_array
@@ -25,8 +27,7 @@ from numpy.ma import masked    as numpy_ma_masked
 from collections import Iterable
 from hashlib     import md5 as hashlib_md5
 from marshal     import dumps as marshal_dumps
-from urlparse    import urlparse as urlparse_urlparse
-from urlparse    import urljoin  as urlparse_urljoin
+from math        import ceil as math_ceil
 from os          import getpid, listdir, mkdir, curdir
 from os.path     import isfile       as os_path_isfile
 from os.path     import abspath      as os_path_abspath
@@ -39,10 +40,13 @@ from os.path     import relpath      as os_path_relpath
 from inspect     import getargspec
 from itertools   import product as itertools_product
 from itertools   import izip, izip_longest
-from platform    import system
+from platform    import system, platform, python_version
 from psutil      import virtual_memory, Process
-from math        import ceil as math_ceil
+from sys         import executable as sys_executable
+from urlparse    import urlparse as urlparse_urlparse
+from urlparse    import urljoin  as urlparse_urljoin
 
+from .          import __version__, __file__
 from .constants import CONSTANTS, _file_to_fh
 
 # Are we running on GNU/Linux?
@@ -299,7 +303,6 @@ A chunk of memory is the amount of memory set by `cf.CHUNKSIZE`.
         minncfm = arg[0]
         CONSTANTS['MINNCFM']      = minncfm
         CONSTANTS['FM_THRESHOLD'] = minncfm * CHUNKSIZE()
-    #--- End: if
 
     return old
 #--- End: def
@@ -576,9 +579,7 @@ False
 #---End: if
 
 def close_files(file_format=None):
-    '''
-
-Close open files containing sub-arrays of master data arrays.
+    '''Close open files containing sub-arrays of data arrays.
 
 By default all such files are closed, but this may be restricted to
 files of a particular format.
@@ -608,7 +609,7 @@ If there are no appropriate open files then no action is taken.
 >>> cf.close_files('netCDF')
 >>> cf.close_files('PP')
 
-'''
+    '''
     if file_format is not None:
         if file_format in _file_to_fh:
             for fh in _file_to_fh[file_format].itervalues():
@@ -624,10 +625,7 @@ If there are no appropriate open files then no action is taken.
 #---End: def
 
 def close_one_file(file_format=None):
-    '''
-
-Close an arbitrary open file containing a sub-array of a master data
-array.
+    '''Close an arbitrary open file containing a sub-array of a data array.
 
 By default a file of arbitrary format is closed, but the choice may be
 restricted to files of a particular format.
@@ -666,7 +664,7 @@ If there are no appropriate open files then no action is taken.
 {'netCDF': {'file1.nc': <netCDF4.Dataset at 0x181bcd0>,
             'file3.nc': <netCDF4.Dataset at 0x1d185e9>}}
 
-'''
+    '''
     if file_format is not None:
         if file_format in _file_to_fh and _file_to_fh[file_format]:
             filename, fh = next(_file_to_fh[file_format].iteritems())
@@ -687,7 +685,7 @@ If there are no appropriate open files then no action is taken.
 def open_files(file_format=None):
     '''
 
-Return the open files containing sub-arrays of master data arrays.
+Return the open files containing sub-arrays of data arrays.
 
 By default all such files are returned, but the selection may be
 restricted to files of a particular format.
@@ -1026,7 +1024,6 @@ def parse_indices(data, indices, cyclic=False):
 
                 else:
                     index = index.tolist()
-            #--- End: if
         #--- End: if
                     
         parsed_indices[i] = index    
@@ -1083,7 +1080,6 @@ indices must contain an index for each dimension of the input array.
         for axis in gg:
             array = take(array, indices[axis], axis=axis)
             indices[axis] = slice(None)
-        #--- End: for
 
         if len_gg < len(indices):
             array = array[tuple(indices)]
@@ -1144,7 +1140,7 @@ def set_subspace(array, indices, value):
                         stop = start + 2
                         y.append(slice(start, stop))
                         start = stop
-                    #--- End: for
+                    #--- End: while
                     indices2.append(y)
                 else:
                     indices2.append((slice(None),))
@@ -1313,7 +1309,6 @@ False
         return eq(y, rtol=rtol, atol=atol,
                   ignore_fill_value=ignore_fill_value,
                   traceback=traceback)
-    #--- End: if
 
     eq = getattr(y, 'equals', None)
     if callable(eq):
@@ -1321,7 +1316,6 @@ False
         return eq(x, rtol=rtol, atol=atol,
                   ignore_fill_value=ignore_fill_value,
                   traceback=traceback)
-    #--- End: if
 
     if isinstance(x, numpy_ndarray):
         if isinstance(y, numpy_ndarray):
@@ -1353,7 +1347,6 @@ def set_equals(x, y, rtol=None, atol=None, ignore_fill_value=False,
         return eq(y, rtol=rtol, atol=atol,
                   ignore_fill_value=ignore_fill_value,
                   traceback=traceback)
-    #--- End: if
 
     eq = getattr(y, 'set_equals', None)
     if callable(eq):
@@ -1361,7 +1354,6 @@ def set_equals(x, y, rtol=None, atol=None, ignore_fill_value=False,
         return eq(x, rtol=rtol, atol=atol,
                   ignore_fill_value=ignore_fill_value,
                   traceback=traceback)
-    #--- End: if
 
     return equals(x, y, rtol=rtol, atol=atol,
                   ignore_fill_value=ignore_fill_value,
@@ -2138,7 +2130,6 @@ names:
             axis_indices = range(o.ndim)
         else:
             axis_indices = axes
-        #--- End: if
     else:
         axis_keys = o.axes(axes, **kwargs)
         axis_indices = list()
@@ -2171,21 +2162,17 @@ names:
                 steps[index] = min_step
                 
             else:
-                steps[index] = int(axis_size/n_chunks)
-                
+                steps[index] = int(axis_size/n_chunks)                
                 break
-            #--- End: if
         #--- End: for
     else:
         steps = [1] * len(sizes)
-    #--- End: if
     
     # use recursion to slice out each 2D horizontal section
     if data:
         d = dict()
     else:
         fl = []
-    #--- End: if
     
     indices = [slice(None)] * len(sizes)
     
@@ -2205,22 +2192,18 @@ names:
                 d[tuple([x.start for x in indices])] = o[tuple(indices)]
             else:
                 fl.append(o.subspace[tuple(indices)])
-            #--- End: if
             nl_vars['count'] += 1
             return
-        #--- End: if
         
         if current_index in axis_indices:
             loop_over_index(current_index - 1)
             return
-        #--- End: if
         
         for i in range(0, sizes[current_index], steps[current_index]):
             if not stop is None and nl_vars['count'] >= stop:
                 return
             indices[current_index] = slice(i, i + steps[current_index])
             loop_over_index(current_index - 1)
-        #--- End: for
     #--- End: def
     
     current_index = len(sizes) - 1
@@ -2230,5 +2213,17 @@ names:
         return d
     else:
         return fl
-    #--- End: if
+#--- End: def
+
+def ENVIRONMENT():
+    '''
+'''
+    print 'Platform:'      , platform() 
+    print 'HDF5 library:'  , netCDF4. __hdf5libversion__
+    print 'netcdf library:', netCDF4.__netcdf4libversion__
+    print 'python:'        , python_version()   , sys_executable
+    print 'netCDF4:'       , netCDF4.__version__, os_path_abspath(netCDF4.__file__)
+    print 'numpy:'         , numpy__version__   , os_path_abspath(numpy__file__)
+    print 'psutil:'        , psutil.__version__ , os_path_abspath(psutil.__file__)
+    print 'cf:'            , __version__        , os_path_abspath(__file__)
 #--- End: def
