@@ -105,7 +105,8 @@ class DataTest(unittest.TestCase):
     
                 for n, (j, i) in enumerate(((34, 23), (0, 0), (-1, -1),
                                             (slice(40, 50), slice(58, 60)),
-                                            (Ellipsis, Ellipsis),
+                                            (Ellipsis, slice(None)),
+                                            (slice(None), Ellipsis),
                                         )):
                     n = -n-1
                     for dvalue, avalue in ((n, n), (cf.masked, numpy.ma.masked), (n, n)):
